@@ -68,9 +68,9 @@ void Fl_Window::_Fl_Window() {
 }
 
 Fl_Window::Fl_Window(int X,int Y,int W, int H, const char *l) :
-  Fl_Group(X, Y, W, H, l),
-  pWindowDriver(Fl_Window_Driver::newWindowDriver(this))
+  Fl_Group(X, Y, W, H, l)
 {
+  pWindowDriver = Fl_Window_Driver::newWindowDriver(this);
   _Fl_Window();
   set_flag(FORCE_POSITION);
   if (!parent()) clear_visible();
@@ -79,9 +79,9 @@ Fl_Window::Fl_Window(int X,int Y,int W, int H, const char *l) :
 
 Fl_Window::Fl_Window(int W, int H, const char *l) :
 // fix common user error of a missing end() with current(0):
-Fl_Group((Fl_Group::current(0),0), 0, W, H, l),
-pWindowDriver(Fl_Window_Driver::newWindowDriver(this))
+Fl_Group((Fl_Group::current(0),0), 0, W, H, l)
 {
+  pWindowDriver = Fl_Window_Driver::newWindowDriver(this);
   _Fl_Window();
   clear_visible();
 }
@@ -876,3 +876,10 @@ const Fl_Image* Fl_Window::shape() {return pWindowDriver->shape();}
 
 /** Returns true when a window is being rescaled */
 bool Fl_Window::is_a_rescale() {return Fl_Window_Driver::is_a_rescale_;}
+
+/** Returns a platform-specific identification of a shown window, or 0 if not shown.
+ \li X11 platform: the window's XID.
+ \li macOS platform: The window number of the window’s window device.
+ \li other platforms: 0.
+ */
+fl_uintptr_t Fl_Window::os_id() { return pWindowDriver->os_id();}
