@@ -62,8 +62,8 @@ Fl_Wayland_Gl_Window_Driver::Fl_Wayland_Gl_Window_Driver(Fl_Gl_Window *win) : Fl
 void Fl_Wayland_Gl_Window_Driver::init() {
   EGLint major, minor;
   
-  if (!fl_display) Fl::screen_driver()->open_display();
-  egl_display = eglGetDisplay((EGLNativeDisplayType) fl_display);
+  if (!Fl_Wayland_Screen_Driver::wl_display) Fl::screen_driver()->open_display();
+  egl_display = eglGetDisplay((EGLNativeDisplayType) Fl_Wayland_Screen_Driver::wl_display);
   if (egl_display == EGL_NO_DISPLAY) {
     Fl::fatal("Can't create egl display\n");
   }
@@ -77,17 +77,17 @@ void Fl_Wayland_Gl_Window_Driver::init() {
   //printf("EGL has %d configs\n", configs_count);
   eglBindAPI(EGL_OPENGL_API);
   
-  gl_event_queue = wl_display_create_queue(fl_display);
+  gl_event_queue = wl_display_create_queue(Fl_Wayland_Screen_Driver::wl_display);
 }
 
 
 char *Fl_Wayland_Gl_Window_Driver::alpha_mask_for_string(const char *str, int n, int w, int h, Fl_Fontsize fs)
 {
   // write str to a bitmap just big enough
-  Window save_win = fl_window;
-  fl_window = NULL;
+  struct wld_window *save_win = Fl_Wayland_Window_Driver::wld_window;
+  fl_window = Fl_Wayland_Window_Driver::wld_window = NULL;
   Fl_Image_Surface *surf = new Fl_Image_Surface(w, h);
-  fl_window = save_win;
+  fl_window = Fl_Wayland_Window_Driver::wld_window = save_win;
   Fl_Font f=fl_font();
   Fl_Surface_Device::push_current(surf);
   fl_color(FL_BLACK);
@@ -246,7 +246,7 @@ void Fl_Wayland_Gl_Window_Driver::make_current_before() {
       struct wl_callback *callback = wl_surface_frame(surface);
       wl_surface_commit(surface);
       wl_callback_add_listener(callback, &gl_surface_frame_listener, &done);
-      while (!done) wl_display_dispatch(fl_display);
+      while (!done) wl_display_dispatch(Fl_Wayland_Screen_Driver::wl_display);
     }
   }
 }
@@ -301,11 +301,11 @@ void Fl_Wayland_Gl_Window_Driver::swap_buffers() {
   if (egl_surface) {
     //eglSwapInterval(egl_display, 0); // doesn't seem to have any effect in this context
     if (!egl_resize_in_progress) {
-      while (wl_display_prepare_read(fl_display) != 0) {
-        wl_display_dispatch_pending(fl_display);
+      while (wl_display_prepare_read(Fl_Wayland_Screen_Driver::wl_display) != 0) {
+        wl_display_dispatch_pending(Fl_Wayland_Screen_Driver::wl_display);
       }
-      wl_display_read_events(fl_display);
-      wl_display_dispatch_queue_pending(fl_display, gl_event_queue);
+      wl_display_read_events(Fl_Wayland_Screen_Driver::wl_display);
+      wl_display_dispatch_queue_pending(Fl_Wayland_Screen_Driver::wl_display,  gl_event_queue);
     }
     egl_resize_in_progress = false;
     eglSwapBuffers(Fl_Wayland_Gl_Window_Driver::egl_display, egl_surface);
