@@ -157,8 +157,6 @@ extern const char *fl_bg2;
 // end of extern additions workaround
 
 
-FL_EXPORT struct wl_display *fl_display = NULL;
-
 static bool has_xrgb = false;
 
 
@@ -196,14 +194,14 @@ static void do_set_cursor(struct seat *seat, struct wl_cursor *wl_cursor = NULL)
 }
 
 static uint32_t ptime;
-FL_EXPORT uint32_t fl_event_time;
+static uint32_t wld_event_time;
 static int px, py;
 
 
 static void set_event_xy(Fl_Window *win) {
   // turn off is_click if enough time or mouse movement has passed:
   if (abs(Fl::e_x_root-px)+abs(Fl::e_y_root-py) > 3 ||
-      fl_event_time >= ptime+1000) {
+      wld_event_time >= ptime+1000) {
     Fl::e_is_click = 0;
 //fprintf(stderr, "Fl::e_is_click = 0\n");
   }
@@ -221,10 +219,13 @@ static inline void checkdouble() {
   }
   px = Fl::e_x_root;
   py = Fl::e_y_root;
-  ptime = fl_event_time;
+  ptime = wld_event_time;
 }
 
 
+struct wl_display *Fl_Wayland_Screen_Driver::wl_display = NULL;
+
+
 Fl_Window *Fl_Wayland_Screen_Driver::surface_to_window(struct wl_surface *surface) {
   Fl_X *xp = Fl_X::first;
   while (xp) {
@@ -301,7 +302,7 @@ static void pointer_motion(void *data,
   Fl::e_y = wl_fixed_to_int(surface_y) / f;
   Fl::e_y_root = Fl::e_y + win->y();
 //fprintf(stderr, "FL_MOVE on win=%p to x:%dx%d root:%dx%d\n", win, Fl::e_x, Fl::e_y, Fl::e_x_root, Fl::e_y_root);
-  fl_event_time = time;
+  wld_event_time = time;
   set_event_xy(win);
   Fl::handle(FL_MOVE, win);
 }
@@ -320,7 +321,7 @@ static void pointer_button(void *data,
   int event = 0;
   Fl_Window *win = Fl_Wayland_Screen_Driver::surface_to_window(seat->pointer_focus);
   if (!win) return;
-  fl_event_time = time;
+  wld_event_time = time;
   if (button == BTN_LEFT && state == WL_POINTER_BUTTON_STATE_PRESSED && seat->pointer_focus == NULL &&
       fl_xid(win)->kind == Fl_Wayland_Window_Driver::DECORATED) {
     // click on titlebar
@@ -355,7 +356,7 @@ static void pointer_axis(void *data,
   struct seat *seat = (struct seat*)data;
   Fl_Window *win = Fl_Wayland_Screen_Driver::surface_to_window(seat->pointer_focus);
   if (!win) return;
-  fl_event_time = time;
+  wld_event_time = time;
   int delta = wl_fixed_to_int(value) / 10;
 //fprintf(stderr, "FL_MOUSEWHEEL: %c delta=%d\n", axis==WL_POINTER_AXIS_HORIZONTAL_SCROLL?'H':'V', delta);
   // allow both horizontal and vertical movements to be processed by the widget
@@ -522,7 +523,7 @@ struct key_repeat_data_t {
 #define KEY_REPEAT_INTERVAL 0.05 // sec
 
 static void key_repeat_timer_cb(key_repeat_data_t *key_repeat_data) {
-  if ((Fl::event() == FL_KEYDOWN || (Fl_Window_Driver::menu_parent() && Fl::event() == FL_ENTER)) && fl_event_time == key_repeat_data->time) {
+  if ((Fl::event() == FL_KEYDOWN || (Fl_Window_Driver::menu_parent() && Fl::event() == FL_ENTER)) && wld_event_time == key_repeat_data->time) {
     Fl::handle(FL_KEYDOWN, key_repeat_data->window);
     Fl::add_timeout(KEY_REPEAT_INTERVAL, (Fl_Timeout_Handler)key_repeat_timer_cb, key_repeat_data);
   }
@@ -680,7 +681,7 @@ fprintf(stderr, "key %s: sym: %-12s(%d) code:%u fl_win=%p, ", action, buf, sym,
   }
   // end of part used only without text-input-unstable-v3
   
-  fl_event_time = time;
+  wld_event_time = time;
   int event = (state == WL_KEYBOARD_KEY_STATE_PRESSED ? FL_KEYDOWN : FL_KEYUP);
   // Send event to focus-containing top window as defined by FLTK,
   // otherwise send it to Wayland-defined focus window
@@ -749,7 +750,7 @@ void text_input_enter(void *data, struct zwp_text_input_v3 *zwp_text_input_v3,
     zwp_text_input_v3_set_cursor_rectangle(zwp_text_input_v3,  x,  y,  width, height);
   }
   zwp_text_input_v3_commit(zwp_text_input_v3);
-  wl_display_roundtrip(fl_display);
+  wl_display_roundtrip(Fl_Wayland_Screen_Driver::wl_display);
 }
 
 void text_input_leave(void *data, struct zwp_text_input_v3 *zwp_text_input_v3,
@@ -1059,7 +1060,6 @@ Fl_Wayland_Screen_Driver::Fl_Wayland_Screen_Driver() : Fl_Screen_Driver() {
 }
 
 void Fl_Wayland_Screen_Driver::open_display_platform() {
-  struct wl_display *wl_display;
   struct wl_registry *wl_registry;
   
   static bool beenHereDoneThat = false;
@@ -1071,7 +1071,6 @@ void Fl_Wayland_Screen_Driver::open_display_platform() {
   if (!wl_display) {
     Fl::fatal("No Wayland connection\n");
   }
-  fl_display = wl_display;
   wl_list_init(&seats);
   wl_list_init(&outputs);
 
@@ -1090,8 +1089,9 @@ void Fl_Wayland_Screen_Driver::open_display_platform() {
 }
 
 void Fl_Wayland_Screen_Driver::close_display() {
-  Fl::remove_fd(wl_display_get_fd(fl_display));
-  wl_display_disconnect(fl_display);
+  Fl::remove_fd(wl_display_get_fd(Fl_Wayland_Screen_Driver::wl_display));
+  wl_display_disconnect(Fl_Wayland_Screen_Driver::wl_display);
+  Fl_Wayland_Screen_Driver::wl_display = NULL;
 }
 
 
@@ -1112,7 +1112,7 @@ void Fl_Wayland_Screen_Driver::init_workarea()
 
 
 int Fl_Wayland_Screen_Driver::x() {
-  if (!fl_display) open_display();
+  if (!Fl_Wayland_Screen_Driver::wl_display) open_display();
   Fl_Wayland_Screen_Driver::output *output;
   wl_list_for_each(output, &outputs, link) {
     break;
@@ -1121,7 +1121,7 @@ int Fl_Wayland_Screen_Driver::x() {
 }
 
 int Fl_Wayland_Screen_Driver::y() {
-  if (!fl_display) open_display();
+  if (!Fl_Wayland_Screen_Driver::wl_display) open_display();
   Fl_Wayland_Screen_Driver::output *output;
   wl_list_for_each(output, &outputs, link) {
     break;
@@ -1130,7 +1130,7 @@ int Fl_Wayland_Screen_Driver::y() {
 }
 
 int Fl_Wayland_Screen_Driver::w() {
-  if (!fl_display) open_display();
+  if (!Fl_Wayland_Screen_Driver::wl_display) open_display();
   Fl_Wayland_Screen_Driver::output *output;
   wl_list_for_each(output, &outputs, link) {
     break;
@@ -1139,7 +1139,7 @@ int Fl_Wayland_Screen_Driver::w() {
 }
 
 int Fl_Wayland_Screen_Driver::h() {
-  if (!fl_display) open_display();
+  if (!Fl_Wayland_Screen_Driver::wl_display) open_display();
   Fl_Wayland_Screen_Driver::output *output;
   wl_list_for_each(output, &outputs, link) {
     break;
@@ -1149,7 +1149,7 @@ int Fl_Wayland_Screen_Driver::h() {
 
 
 void Fl_Wayland_Screen_Driver::init() {
-  if (!fl_display) open_display();
+  if (!Fl_Wayland_Screen_Driver::wl_display) open_display();
 }
 
 
@@ -1219,8 +1219,8 @@ void Fl_Wayland_Screen_Driver::beep(int type)
 
 void Fl_Wayland_Screen_Driver::flush()
 {
-  if (fl_display) {
-    wl_display_flush(fl_display);
+  if (Fl_Wayland_Screen_Driver::wl_display) {
+    wl_display_flush(Fl_Wayland_Screen_Driver::wl_display);
   }
 }
 
@@ -1245,13 +1245,6 @@ void Fl_Wayland_Screen_Driver::grab(Fl_Window* win)
   } else {
     if (Fl::grab()) {
       // We must keep the grab in the non-EWMH fullscreen case
-      if (!fullscreen_win ) {
-        //XUngrabKeyboard(fl_display, fl_event_time);
-      }
-      //XUngrabPointer(fl_display, fl_event_time);
-      // this flush is done in case the picked menu item goes into
-      // an infinite loop, so we don't leave the X server locked up:
-      //XFlush(fl_display);
       Fl::grab_ = 0;    // FIXME: Fl::grab_ "should be private", but we need
                         // a way to *set* the variable from the driver!
       fl_fix_focus();
