@@ -69,7 +69,10 @@ extern "C" {
     int table##_callback_row(table *);                                                             \
     int table##_callback_context(table *);                                                         \
     void *table##_scrollbar(const table *);                                                        \
-    void *table##_hscrollbar(const table *);
+    void *table##_hscrollbar(const table *);                                                       \
+    int table##_find_cell(const table *self, int ctx, int r, int c, int *x, int *y, int *w,        \
+                          int *h);                                                                 \
+    int table##_cursor2rowcol(const table *self, int *r, int *c, int *flag);
 
 WIDGET_DECLARE(Fl_Table)
 
